compContourM1ucompContourM1u, namely the list
COutST$CharST. It makes possible
to obtain some useful information without saving
any file on the disk, and it can be easily modified
by the users according to their wishes.
getCharSTM1u(Tau, N, M, P, BriefDQMat, CharST, IsFirst)CTechST$BriefOutputI = 1. See
the details below.getCharSTM1u
(when CharST is initialized)
and equal to zero otherwise.getCharSTM1u returns a list with the following
components:[-1,1]^M bounding box.AVec zero.BVec zero.M > 4) the component is missing
(for M <= 4<="" code="">) the matrix with M + P
columns containing (in rows) all the distinct
regression Tau-quantile hyperplane
coefficients c(BVec, AVec) normalized
with |BVec|, rounded to the eighth
decimal digit, and sorted lexicographically.
This matrix can be used for the computation
of the regression Tau-quantile contour.=>P = 1, then CharMaxMat has
only three rows:
c(UVec, max(|BVec|)),c(UVec, max(Lambda)), andc(UVec, max(Lambda/|BVec|)),P > 1, then the rows of
CharMaxMat are as follows:
c(UVec, max(|BVec|)),c(UVec, max(Lambda)),c(UVec, max(Lambda/|BVec|)),c(UVec, max(|c(a_2,...,a_P)|)),c(UVec, max(|c(a_2,...,a_P)|/|BVec|)),c(UVec, max(|a_2|)),c(UVec, max(|a_2|/|BVec|)),...,c(UVec, max(|a_P|)), andc(UVec, max(|a_P|/|BVec|)),P = 2,
then the last two rows are missing for not
being included twice.
P = 1, then CharMinMat has
only three rows:
c(UVec, min(|BVec|)),c(UVec, min(Lambda)), andc(UVec, min(Lambda/|BVec|)),P > 1, then CharMinMat
has five rows:
c(UVec, min(|BVec|)),c(UVec, min(Lambda)),c(UVec, min(Lambda/|BVec|)),c(UVec, min(|c(a_2,...,a_P)|)), andc(UVec, min(|c(a_2,...,a_P)|/|BVec|)),|| symbolizes the Euclidean norm,
and that the vertices (UVec) in the rows of
CharMaxMat and CharMinMat are generally
different and denote (one of) the direction(s) where
the row maximum or minimum is attained.
compContourM1u.
First, it is called with
BriefDQMat = NULL,
CharST = NULL and
IsFirst = 1 to initialize
the output list CharST, and then
it is called with IsFirst = 0
successively for the content of each potential
output file corresponding to
CTechST$BriefOutputI = 1, i.e., even if
the output file(s) are not stored on the disk owing to
CTechST$OutSaveI = 0. It still remains to describe in detail the content of possible output files, describing the optimal conic segmentation of the directional space that lies behind the optimization problem involved.
If CTechST$BriefOutputI = 1, then the rows of such
files are vectors of length 1+1+M+M+P+1 of the form
c(ConeID, Nu, UVec, BDVec, ADVec, LambdaD) where
M > 2, then a cone can appear in
the output repeatedly (under different numbers).
[-1,1]^M. The
max normalization is used if the breadth-first
search algorithm is employed and the L2
normalization is used in the other case (when
M = 2 and CTechST$D2SpecI = 1).
c(b_1,...,b_M), i.e.,
the constant vector denominator of BVec,
where
BVec = BDVec/(t(BDVec)%*%UVec).
c(a_1,...,a_P), i.e.,
the constant vector denominator of AVec,
where
AVec = ADVec/(t(BDVec)%*%UVec).
Lambda = LambdaD/(t(BDVec)%*%UVec).
Recall that c(BVec, AVec) stands for the coefficients
of the regression quantile hyperplane associated with
UVec and that Lambda denotes the Lagrange
multiplier equal to the optimal value Psi of the objective
function for that direction.
If CTechST$BriefOutputI = 0, then the rows of the
potential output file(s) are longer
(of length 1+1+M+M+P+1+(P+M-1)*M+(P+M-1))
because they contain two more vectors appended at the end.
The rows are of the form
c(ConeID, Nu, UVec, BDVec, ADVec, LambdaD, vec(VUMat), IZ)
where
MuR0Vec associated with zero residuals,
MuR0Vec
= (VUMat%*%UVec)/(t(BDVec)%*%UVec).
That is to say that all directions from the
interior of the cone result in the regression
Tau-quantile hyperplanes containing
the same P+M-1 observations because all
such hyperplanes are the same up to a scaling
factor multiplying their coefficients.M+P-1 observations with zero residuals
for all directions from the interior of the cone.
##Run print(getCharSTM1u) to examine the default setting.
Run the code above in your browser using DataLab