compContourM2ucompContourM2u, namely the list
COutST$CharST. It makes possible
to obtain some useful information without saving
any file on the disk, and it can be easily modified
by the users according to their wishes.
getCharSTM2u(Tau, N, M, P, BriefDQMat, CharST, IsFirst)CTechST$BriefOutputI = 1. See
the details below.getCharSTM2u
(when CharST is initialized)
and equal to zero otherwise.getCharSTM2u returns a list with the following
components:[-1,1]^M bounding boxAVec zero.BVec zero.M > 4) the component is missing
(for M <= 4<="" code="">) the matrix with M + P
columns containing (in rows) all the distinct
regression Tau-quantile hyperplane
coefficients c(BVec, AVec)
rounded to the eighth decimal digit and
sorted lexicographically.
This matrix can be used for the computation
of the regression Tau-quantile contour.=>P = 1, then CharMaxMat has
only two rows:
c(UVec, max(Psi)), andc(UVec, max(|MuBRow|)),P > 1, then the rows of
CharMaxMat are as follows:
c(UVec, max(|Psi|)),c(UVec, max(MuBRow)),c(UVec, max(|c(a_2,...,a_P)|)),c(UVec, max(|a_2|)),...,c(UVec, max(|a_P|)),P = 2,
then the last row is missing for not
being included twice.
P = 1, then CharMinMat has
only two rows:
c(UVec, min(Psi)), andc(UVec, min(|MuBRow|)),P > 1, then CharMinMat
has three rows:
c(UVec, min(Psi)),c(UVec, min(|MuBRow|)), andc(UVec, min(|c(a_2,...,a_P)|)),|| symbolizes the Euclidean norm,
and that the vertices (UVec) in the rows of
CharMaxMat and CharMinMat are generally
different and denote (one of) the direction(s) where
the row maximum or minimum is attained.
compContourM2u.
First, it is called with
BriefDQMat = NULL,
CharST = NULL and
IsFirst = 1 to initialize
the output list CharST, and then
it is called with IsFirst = 0
successively for the content of each potential
output file corresponding to
CTechST$BriefOutputI = 1, i.e., even if
the output file(s) are not stored on the disk owing to
CTechST$OutSaveI = 0. It still remains to describe in detail the content of possible output files, describing the optimal conic segmentation of the directional space that lies behind the optimization problem involved.
If CTechST$BriefOutputI = 1, then the rows of such
files are vectors of length 1+1+M+P*M+M of the form
c(ConeID, Nu, UVec, vec(ACOMat), MuBRow) where
M > 2, then a cone can appear in
the output repeatedly (under different numbers).
[-1,1]^M. The
max normalization is used if the breadth-first
search algorithm is employed and the L2
normalization is used in the other case (when
M = 2 and CTechST$D2SpecI = 1).
AVec,
AVec = ACOMat%*%UVec.
BVec.
Its inner product with UVec is equal
to the optimal value Psi of the objective
function for that direction.
Recall that c(BVec, AVec) stands for the coefficients
of the regression quantile hyperplane associated with
UVec and always BVec = UVec.
If CTechST$BriefOutputI = 0, then the rows of the
potential output file(s) are longer
(of length 1+1+P*M+M+P+P)
because they contain two more vectors appended at the end.
The rows are of the form
c(ConeID, Nu, UVec, vec(ACOMat), MuBRow, MuR0Row, IZ)
where
Tau-quantile hyperplanes
containing the same P observations.P observations with zero residuals
for all directions from the interior of the cone.
##Run print(getCharSTM2u) to examine the default setting.
Run the code above in your browser using DataLab